require('dotenv').config();
var MongoClient = require('mongodb').MongoClient;
var express = require ('express');
const mongoose = require('mongoose');
const Article= require('./models/article')
const articleRouter = require('./routes/articles')
const methodOverride = require('method-override')
var session = require ('express-session');
var flash = require('express-flash');
const MongoDBStore = require('connect-mongo')(session);
var bodyParser= require ('body-parser');
var path=require('path');
 
var validator = require ('express-validator');                       
const expressSanitizer = require('express-sanitizer');
const app = express()
const port = 8000;

//connecting to mongodb
var url = "mongodb://localhost/members";
MongoClient.connect(url, function(err, db) {
		  if (err) throw err;
		console.log("Database created!");
		  db.close();     });

//connecting to database using mongoose library
var myurl = "mongodb://localhost/myfooditems";
mongoose.connect(myurl, {
	useNewUrlParser: true,
	useUnifiedTopology: true, useCreateIndex: true
});

const connection=mongoose.connection;
connection.once('open',()=>{
console.log('connected..')});

app.use(express.urlencoded({ extended: false }));
app.use(bodyParser.urlencoded({ extended: true }));
app.use(methodOverride('_method'))
app.use(expressSanitizer());                                                                                          

//mongo session
let mongoStore=new MongoDBStore({
	mongooseConnection:connection,
	collection:'sessions'});

//added for session management 
app.use(session({
	secret: process.env.COOKIE_SECRET,
	resave: false,
	saveUninitialized: false,
	cookie: { expires: 600000 } }));                                                                                                                               
app.use(flash());
app.set('views', path.join(__dirname, 'views'));
require('./routes/main')(app);
app.set('views',__dirname + '/views');
app.set('view engine', 'ejs'); 
app.engine('html', require('ejs').renderFile);

//if user is not loggedin, the user is redirected to the login page
const redirectLogin = (req, res, next) => { if 
(!req.session.userId ) {
	res.redirect('./login') }
else { next (); } }
//foodpage route displays food data
app.get('/foodpage',redirectLogin, async (req, res) => {
   const articles = await Article.find().sort({ createdAt: 'desc' })
  res.render('articles/index', { articles: articles })
});

//save page route
app.get('/savedpage', function (req, res) {
res.render('articles/save.html');});

app.use('/articles', articleRouter);


app.listen(port, () => console.log(`Example app listening on port ${port}!`));
